# bgzip: blocked gzip streams
_bgzip_ provides streams for blocked gzip files.

## Installation
```
pip install bgzip
```

## Links
Project home page [GitHub](https://github.com/xbrianh/bgzip)  
Package distribution [PyPI](https://pypi.org/project/bgzip/)

### Bugs
Please report bugs, issues, feature requests, etc. on [GitHub](https://github.com/xbrianh/bgzip).

![](https://travis-ci.org/xbrianh/bgzip.svg?branch=master) ![](https://badge.fury.io/py/bgzip.svg)
